// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	cxctods9.cc --- convert CXC into ds9 regions
//
//	DESCRIPTION:
//		Convert the content of a CXC region file into a ds9 region
//
//	CHANGE HISTORY:
//		UL, 2001-08-13: 1.0.0: - initial version
//
//	AUTHOR:
//		U. Lammers (UL), Mon Aug 13 15:00:56 MET DST 2001
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/imgdisplay/conv/cxctods9.cc,v 1.4 2002/09/18 15:22:52 ulammers Exp $
//

#include "Ds9.h"
#include "ASCregion.h"
#include "param.h"
#include "stringutil.h"

#include "cxctods9.h"

void cxctods9()
{
	InASCregionTable intab(stringParameter("table"));
	::GeoRegion cxcreg;
	intab>>cxcreg;
	string regTypeStr = uppercase(stringParameter("regtype"));
	ImageDisplayer::CoordType regType;
	if (regTypeStr == "LINEAR")
		regType = ImageDisplayer::LINEAR;
	else if (regTypeStr == "FK5")
		regType = ImageDisplayer::FK5;
	else
		regType = ImageDisplayer::IMAGE;

	ImageDisplayer::Region r(cxcreg, regType);
	std::cout<<r<<std::endl;
	cxcreg.free();
} // cxctods9()
