// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                       (c) 1997 European Space Agency
//
//---------------------------------------------------------------------------
//
//	SAOtng.h:	--- wrapper class around SAOtng
//
//	DESCRIPTION:
//		A class `SAOtng' is defined which implements the `ImageDisplayer'
//		interface using the image display program SAOtng.
//
//	CHANGE HISTORY:
//		UL, 1998-10-20: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Tue Oct 20 15:23:28 MET DST 1998
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/imgdisplay/src/SAOtng.h,v 1.12 2003/03/05 17:19:12 ulammers Exp $
//

#ifndef SAOTNG_H
#define SAOTNG_H

#include "ImageDisplayer.h"

class SAOtng : public virtual ImageDisplayer {
public:
	SAOtng(bool stopViewer = false);

	bool isUp() const { return isRunning(); }

	void flipX() const;
	void flipY() const;

	void zoomIn(ZoomFactor zoomFactor = X1) const;
	void zoomOut(ZoomFactor zoomFactor = X1) const;

	void displayImage(const std::string &dataSetName) const;
	void displayRegion(const std::string &regionTable,
					   CoordType coordType = IMAGE) const;
	void displayRegion(const Region &region) const;

	std::vector<std::string> regionSelectionAsString(
											CoordType coordType = IMAGE) const;
	::GeoRegion regionSelection(CoordType coordType = IMAGE,
							const std::string &ignoreMarkerColor = "") const;

	void deleteRegions() const;
	void send(const std::string &command) const;

	std::vector<std::string> receive(const std::string &command) const;

	void down() const;

	~SAOtng();

private:
	static const std::string Xpaset;	//	send commands to SAOtng
	static const std::string Xpaget;	//	read settings from SAOtng
	static const std::string TITENV;	//	"SAOtng-$LOGNAME"

	//	methods
	bool isRunning() const;
		//	Is SAOtng running?

	bool isThere() const;
		//	Is the executable there?

	void execBackground(const std::string &command) const;
		//	execute command in the background

	void setName();		//	figure out name from environment

	//	data members
	std::string	_title;	//	window title of SAOtng
	std::string	_Saotng; //	name of the game
}; // SAOtng;

#endif

